You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@flink.apache.org by kk...@apache.org on 2019/07/29 13:51:44 UTC

[flink] branch release-1.8 updated: [FLINK-9526][e2e] Fix unstable BucketingSink end-to-end test

This is an automated email from the ASF dual-hosted git repository.

kkloudas pushed a commit to branch release-1.8
in repository https://gitbox.apache.org/repos/asf/flink.git


The following commit(s) were added to refs/heads/release-1.8 by this push:
     new c4e9743  [FLINK-9526][e2e] Fix unstable BucketingSink end-to-end test
c4e9743 is described below

commit c4e97436bb0ef5a658ff4a9117b4776d58f888c0
Author: ifndef-SleePy <mm...@gmail.com>
AuthorDate: Tue Jul 23 14:29:36 2019 +0200

    [FLINK-9526][e2e] Fix unstable BucketingSink end-to-end test
---
 flink-end-to-end-tests/test-scripts/test_streaming_bucketing.sh | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/flink-end-to-end-tests/test-scripts/test_streaming_bucketing.sh b/flink-end-to-end-tests/test-scripts/test_streaming_bucketing.sh
index ba43e21..b3d19fd 100755
--- a/flink-end-to-end-tests/test-scripts/test_streaming_bucketing.sh
+++ b/flink-end-to-end-tests/test-scripts/test_streaming_bucketing.sh
@@ -21,8 +21,9 @@ source "$(dirname "$0")"/common.sh
 
 TEST_PROGRAM_JAR=${END_TO_END_DIR}/flink-bucketing-sink-test/target/BucketingSinkTestProgram.jar
 
-# enable DEBUG logging level to retrieve truncate length later
-sed -i -e 's/#log4j.logger.org.apache.flink=INFO/log4j.logger.org.apache.flink=DEBUG/g' $FLINK_DIR/conf/log4j.properties
+# enable DEBUG logging level for the BucketingSink to retrieve truncate length later
+echo "" >> $FLINK_DIR/conf/log4j.properties
+echo "log4j.logger.org.apache.flink.streaming.connectors.fs.bucketing.BucketingSink=DEBUG" >> $FLINK_DIR/conf/log4j.properties
 
 set_conf_ssl
 start_cluster